| Title: | 'AWS' Java 'SDK' for R |
|---|---|
| Description: | Make the compiled Java modules of the Amazon Web Services ('AWS') 'SDK' available to be used in downstream R packages interacting with 'AWS'. See <https://aws.amazon.com/sdk-for-java> for more information on the 'AWS' 'SDK' for Java. |
| Authors: | Gergely Daroczi <[email protected]> |
| Maintainer: | Gergely Daroczi <[email protected]> |
| License: | AGPL-3 |
| Version: | 1.11.189-1 |
| Built: | 2026-05-19 06:27:55 UTC |
| Source: | https://github.com/daroczig/awr |
This R package makes the jar files of the AWS SDK for Java
available to be used in downstream R packages. Please note the
installation instructions for the System Requirements in the
README.md.
https://aws.amazon.com/sdk-for-java
## Not run: library(rJava) client <- .jnew("com.amazonaws.services.s3.AmazonS3Client") kc$getS3AccountOwner()$getDisplayName() ## End(Not run)## Not run: library(rJava) client <- .jnew("com.amazonaws.services.s3.AmazonS3Client") kc$getS3AccountOwner()$getDisplayName() ## End(Not run)
Asserts if AWS SDK for Java jar files are available
assert_awr_jars()assert_awr_jars()
invisible TRUE on success, otherwise error
Checks if AWS SDK for Java jar files are available
check_awr_jars()check_awr_jars()
TRUE on success, informative message as a string on error
Tests if AWS SDK for Java jar files are available
test_awr_jars()test_awr_jars()
boolean